ProgressOverlayState class

Constructors

ProgressOverlayState({bool isProgressShown = true, ProgressWidgetBuilder? progressWidgetBuilder, dynamic progress, required bool isOverlayShown})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isOverlayShown bool
final
isProgressShown bool
final
isUsingCustomProgressWidgetBuilder bool
no setter
isVisible bool
no setter
progress → dynamic
final
progressWidgetBuilder ProgressWidgetBuilder?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

copyWith({bool? isProgressShown, ProgressWidgetBuilder? progressWidgetBuilder()?, dynamic progress()?, bool? isOverlayShown}) ProgressOverlayState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited